"""
ReMap_get_transcription_factor_binding

Get transcription factor binding sites from ReMap database for specific genes and cell types
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def ReMap_get_transcription_factor_binding(
    gene_name: str,
    cell_type: Optional[str] = "HepG2",
    limit: Optional[int] = 10,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Get transcription factor binding sites from ReMap database for specific genes and cell types

    Parameters
    ----------
    gene_name : str
        Gene symbol (e.g., BRCA1, TP53, MYC)
    cell_type : str
        Cell type (e.g., HepG2, K562, MCF-7)
    limit : int
        Number of results to return
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "ReMap_get_transcription_factor_binding",
            "arguments": {
                "gene_name": gene_name,
                "cell_type": cell_type,
                "limit": limit,
            },
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["ReMap_get_transcription_factor_binding"]



"""
ensembl_get_variants

Get genetic variants in a genomic region. Returns SNP and indel information.
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def ensembl_get_variants(
    region: str,
    species: Optional[str] = "homo_sapiens",
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Get genetic variants in a genomic region. Returns SNP and indel information.

    Parameters
    ----------
    region : str
        Genomic region in format 'chromosome:start-end' (e.g., '13:32315086-32400268')
    species : str
        Species name
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "ensembl_get_variants",
            "arguments": {"region": region, "species": species},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["ensembl_get_variants"]



"""
GTEx_get_expression_summary

Summarize tissue-specific expression (e.g., median TPM) for a gene across GTEx tissues. Use to pr...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def GTEx_get_expression_summary(
    ensembl_gene_id: str,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Summarize tissue-specific expression (e.g., median TPM) for a gene across GTEx tissues. Use to pr...

    Parameters
    ----------
    ensembl_gene_id : str
        Ensembl gene identifier (e.g., 'ENSG00000141510' for TP53).
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "GTEx_get_expression_summary",
            "arguments": {"ensembl_gene_id": ensembl_gene_id},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["GTEx_get_expression_summary"]



"""
PubChem_get_compound_2D_image_by_CID

Get 2D structure image (PNG format) of compound by CID.
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def PubChem_get_compound_2D_image_by_CID(
    cid: int,
    image_size: str,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Get 2D structure image (PNG format) of compound by CID.

    Parameters
    ----------
    cid : int
        Compound ID to get image for, e.g., 2244.
    image_size : str
        Optional parameter, image size, like "200x200" (default).
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "PubChem_get_compound_2D_image_by_CID",
            "arguments": {"cid": cid, "image_size": image_size},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["PubChem_get_compound_2D_image_by_CID"]



"""
gwas_get_associations_for_trait

Get all associations for a specific trait, sorted by p-value (most significant first).
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def gwas_get_associations_for_trait(
    efo_trait: str,
    size: Optional[int] = None,
    page: Optional[int] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Get all associations for a specific trait, sorted by p-value (most significant first).

    Parameters
    ----------
    efo_trait : str
        EFO trait identifier or name
    size : int
        Number of results to return per page
    page : int
        Page number for pagination
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "gwas_get_associations_for_trait",
            "arguments": {"efo_trait": efo_trait, "size": size, "page": page},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["gwas_get_associations_for_trait"]



"""
GO_get_annotations_for_gene

Finds all GO annotations for a specific gene/protein using GOlr search.
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def GO_get_annotations_for_gene(
    gene_id: str,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Finds all GO annotations for a specific gene/protein using GOlr search.

    Parameters
    ----------
    gene_id : str
        A gene identifier such as gene symbol (e.g., 'TP53') or database ID.
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {"name": "GO_get_annotations_for_gene", "arguments": {"gene_id": gene_id}},
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["GO_get_annotations_for_gene"]



"""
get_webpage_title

Fetch a webpage and return the content of its <title> tag.
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def get_webpage_title(
    url: str,
    timeout: int,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Fetch a webpage and return the content of its <title> tag.

    Parameters
    ----------
    url : str
        HTTP or HTTPS URL to fetch (e.g. https://www.example.com)
    timeout : int
        Request timeout in seconds
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {"name": "get_webpage_title", "arguments": {"url": url, "timeout": timeout}},
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["get_webpage_title"]
